@@ -55,6 +55,12 @@ CreditScoreStatusesLiterals = Literal[
 ]
 
 
+CreditScoresModelLiterals = Literal[
+    'vantage_4',
+    'vantage_3'
+]
+
+
 CreditReportBureausLiterals = Literal[
     'experian',
     'equifax',
@@ -183,7 +189,7 @@ class EntityCreditScoresFactorsType(TypedDict):
 class EntityCreditScoresType(TypedDict):
     score: int
     source: CreditReportBureausLiterals
-    model: str
+    model: CreditScoresModelLiterals
     factors: List[EntityCreditScoresFactorsType]
     created_at: str
     factors: EntityCreditScoresFactorsType
@@ -193,7 +199,7 @@ class EntityCreditScoresType(TypedDict):
 class EntityCreditScoresResponse(TypedDict):
     id: str
     status: EntityStatusesLiterals
-    credit_scores: Optional[List[EntityCreditScoresType]]
+    scores: Optional[List[EntityCreditScoresType]]
     error: Optional[ResourceError]
     created_at: str
     updated_at: str
